Change Log
==========

A log of changes by version and date.

======= ========== =====
Version Date       Notes
======= ========== =====
1.2.0   10/16/2014 Initial Version
1.4.0   12/15/2014 Add support for REST 1.3 and 1.4
1.6.0   05/17/2016 Add support for REST 1.5 and 1.6
1.6.1   05/30/2016 Minor bug fixes and sync code between GitHub and PyPI
1.8.0   11/02/2016 Add support for REST 1.7 and 1.8
1.11.0  09/05/2017 Add support for REST 1.9, 1.10, and 1.11
1.11.1  09/06/2017 Minor setup.py change for new PyPI interface 
1.11.2  09/07/2017 Minor setup.py change for new PyPI interface 
1.11.3  09/07/2017 Minor setup.py change for new PyPI interface 
======= ========== =====
